@@ -2,7 +2,6 @@ package Doxygen::Lua;
 
 use warnings;
 use strict;
-use Moose;
 
 =head1 NAME
 
@@ -10,12 +9,11 @@ Doxygen::Lua - Make Doxygen support Lua
 
 =head1 VERSION
 
-Version 0.02
+Version 0.04
 
 =cut
 
-our $VERSION = '0.02';
-has 'mark' => ( is => 'rw', isa => 'Str', default => '--!' );
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -39,6 +37,18 @@ This function will create a Doxygen::Lua object.
 
 =cut
 
+sub new {
+    my ($class, %args) = @_;
+    my $self = bless \%args, $class;
+    $self->_init;
+    return $self;
+}
+
+sub _init {
+    my $self = shift;
+    $self->{mark} = '--!';
+}
+
 =head2 parse
 
 This function will parse the given input file and return the result.
@@ -62,6 +72,10 @@ sub parse {
     foreach my $line (<FH>) {
         chomp $line;
 
+        # include empty lines
+        if ($line =~ m{^\s*$}) {
+            $result .= "\n"
+        }
         # skip normal comments
         next if $line =~ /^\s*--[^!]/;
         # remove end of line comments
@@ -78,6 +92,14 @@ sub parse {
         elsif ($line =~ /^function/) {
             $in_function = 1;
             $line .= q{;};
+            $line =~ s/:/-/;
+            $result .= "$line\n";
+        }
+	#local function start
+   	elsif ($line =~ /^local.+function/) {
+            $in_function = 1;
+            $line .= q{;};
+            $line =~ s/function\s+/function-/;
             $result .= "$line\n";
         }
         # function end
@@ -112,6 +134,12 @@ This function will set the mark style. The default value is "--!".
 
 =cut
 
+sub mark {
+    my ($self, $value) = @_;
+    $self->{mark} = $value if $value;
+    return $self->{mark};
+}
+
 =head1 AUTHOR
 
 Alec Chen, C<< <alec at cpan.org> >>
